==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/OpsGenieConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OpsGenieConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigBuilder>{
  public OpsGenieConfigBuilder() {
    this(false);
  }
  public OpsGenieConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new OpsGenieConfig(), validationEnabled);
  }
  public OpsGenieConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public OpsGenieConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OpsGenieConfig(), validationEnabled);
  }
  public OpsGenieConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfig instance) {
    this(fluent, instance, false);
  }
  public OpsGenieConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiKey(instance.getApiKey()); 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDetails(instance.getDetails()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withNote(instance.getNote()); 
    fluent.withPriority(instance.getPriority()); 
    fluent.withResponders(instance.getResponders()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withSource(instance.getSource()); 
    fluent.withTags(instance.getTags()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OpsGenieConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfig instance) {
    this(instance,false);
  }
  public OpsGenieConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiKey(instance.getApiKey()); 
    this.withApiURL(instance.getApiURL()); 
    this.withDescription(instance.getDescription()); 
    this.withDetails(instance.getDetails()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withNote(instance.getNote()); 
    this.withPriority(instance.getPriority()); 
    this.withResponders(instance.getResponders()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withSource(instance.getSource()); 
    this.withTags(instance.getTags()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.OpsGenieConfig build() {
    OpsGenieConfig buildable = new OpsGenieConfig(fluent.getApiKey(),fluent.getApiURL(),fluent.getDescription(),fluent.getDetails(),fluent.getHttpConfig(),fluent.getMessage(),fluent.getNote(),fluent.getPriority(),fluent.getResponders(),fluent.getSendResolved(),fluent.getSource(),fluent.getTags());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OpsGenieConfigBuilder that = (OpsGenieConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.3.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/OpsGenieConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class OpsGenieConfigBuilder extends OpsGenieConfigFluentImpl<OpsGenieConfigBuilder> implements VisitableBuilder<OpsGenieConfig,OpsGenieConfigBuilder>{
  public OpsGenieConfigBuilder() {
    this(false);
  }
  public OpsGenieConfigBuilder(Boolean validationEnabled) {
    this(new OpsGenieConfig(), validationEnabled);
  }
  public OpsGenieConfigBuilder(OpsGenieConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public OpsGenieConfigBuilder(OpsGenieConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new OpsGenieConfig(), validationEnabled);
  }
  public OpsGenieConfigBuilder(OpsGenieConfigFluent<?> fluent,OpsGenieConfig instance) {
    this(fluent, instance, false);
  }
  public OpsGenieConfigBuilder(OpsGenieConfigFluent<?> fluent,OpsGenieConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiKey(instance.getApiKey()); 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withDescription(instance.getDescription()); 
    fluent.withDetails(instance.getDetails()); 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMessage(instance.getMessage()); 
    fluent.withNote(instance.getNote()); 
    fluent.withPriority(instance.getPriority()); 
    fluent.withResponders(instance.getResponders()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withSource(instance.getSource()); 
    fluent.withTags(instance.getTags()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OpsGenieConfigBuilder(OpsGenieConfig instance) {
    this(instance,false);
  }
  public OpsGenieConfigBuilder(OpsGenieConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiKey(instance.getApiKey()); 
    this.withApiURL(instance.getApiURL()); 
    this.withDescription(instance.getDescription()); 
    this.withDetails(instance.getDetails()); 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMessage(instance.getMessage()); 
    this.withNote(instance.getNote()); 
    this.withPriority(instance.getPriority()); 
    this.withResponders(instance.getResponders()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withSource(instance.getSource()); 
    this.withTags(instance.getTags()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  OpsGenieConfigFluent<?> fluent;
  Boolean validationEnabled;
  public OpsGenieConfig build() {
    OpsGenieConfig buildable = new OpsGenieConfig(fluent.getApiKey(),fluent.getApiURL(),fluent.getDescription(),fluent.getDetails(),fluent.getHttpConfig(),fluent.getMessage(),fluent.getNote(),fluent.getPriority(),fluent.getResponders(),fluent.getSendResolved(),fluent.getSource(),fluent.getTags());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
